<?php

// compatible with WIndows Live Movie Maker build 15.xxx (aka WLMM 2011, or Live Wave 4), released september 2010
// by Roberto Piola, see http://www.ilpiola.it/roberto/automovie

// please adjust these parameters before running the program:

$dir='jpg midres'; // directory where .jpg (photo) files are to be found
$mp3dir='Music'; // directory where .mp3 (audio) files are to be found. empty means no audio
$foname='project'; // project name
$dur=6; // duration of each slide, in seconds
$effects=array( // list of the effects to choose from
  "BowTieHorizontalTransitionTemplate",
  "BowTieVerticalTransitionTemplate",
  "DiagonalBoxOutTransitionTemplate",
  "DiagonalCrossOutTransitionTemplate",
  "ShatterUpLeftTransitionTemplate",
  "ShatterUpRightTransitionTemplate",
  "WhirlwindTransitionTemplate",
  "WhirlwindFromTopTransitionTemplate",
  "FanInTransitionTemplate",
  "FanOutTransitionTemplate",
  "FanUpTransitionTemplate",
  "PageCurlDownLeftTransitionTemplate",
  "PageCurlDownRightTransitionTemplate",
  "PageCurlUpLeftTransitionTemplate",
  "PageCurlUpRightTransitionTemplate",
  "DiagonalDownRightTransitionTemplate",
  "SweepInTransitionTemplate",
  "FilledVDownTransitionTemplate",
  "SweepOutTransitionTemplate",
  "FilledVLeftTransitionTemplate",
  "SweepUpTransitionTemplate",
  "FilledVRightTransitionTemplate",
  "WipeNarrowDownTransitionTemplate",
  "FilledVUpTransitionTemplate",
  "WipeNarrowRightTransitionTemplate",
  "BarsHorizontalTransitionTemplate",
  "WipeNormalDownTransitionTemplate",
  "BarsVerticalTransitionTemplate",
  "WipeNormalRightTransitionTemplate",
  "WipeWideDownTransitionTemplate",
  "WipeWideRightTransitionTemplate",
  "ZigzagHorizontalTransitionTemplate",
  "DissolveTransitionTemplate",
  "ZigzagVerticalTransitionTemplate",
  "DissolveRoughTransitionTemplate",
  "CheckerboardTransitionTemplate",
  "CircleTransitionTemplate",
  "CirclesTransitionTemplate",
  "DiamondTransitionTemplate",
  "EyeTransitionTemplate",
  "HeartTransitionTemplate",
  "KeyholeTransitionTemplate",
  "RectangleTransitionTemplate",
  "StarTransitionTemplate",
  "StarsTransitionTemplate",
  "WheelTransitionTemplate",
  "InsetDownLeftTransitionTemplate",
  "InsetDownRightTransitionTemplate",
  "InsetUpLeftTransitionTemplate",
  "InsetUpRightTransitionTemplate",
  "IrisTransitionTemplate",
  "RevealDownTransitionTemplate",
  "RevealRightTransitionTemplate",
  "SplitHorizontalTransitionTemplate",
  "SplitVerticalTransitionTemplate",
  "ShatterInTransitionTemplate",
  "ShatterRightTransitionTemplate"
  );


// end of parameters



// The following part is took from getid3 demos

// +----------------------------------------------------------------------+
// | PHP version 4.1.0                                                    |
// +----------------------------------------------------------------------+
// | Placed in public domain by Allan Hansen, 2002. Share and enjoy!      |
// +----------------------------------------------------------------------+
// | /demo/demo.audioinfo.class.php                                       |
// |                                                                      |
// | Example wrapper class to extract information from audio files        |
// | through getID3().                                                    |
// |                                                                      |
// | getID3() returns a lot of information. Much of this information is   |
// | not needed for the end-application. It is also possible that some    |
// | users want to extract specific info. Modifying getID3() files is a   |
// | bad idea, as modifications needs to be done to future versions of    |
// | getID3().                                                            |
// |                                                                      |
// | Modify this wrapper class instead. This example extracts certain     |
// | fields only and adds a new root value - encoder_options if possible. |
// | It also checks for mp3 files with wave headers.                      |
// +----------------------------------------------------------------------+
// | Example code:                                                        |
// |   $au = new AudioInfo();                                             |
// |   print_r($au->Info('file.flac');                                    |
// +----------------------------------------------------------------------+
// | Authors: Allan Hansen <ahartemis*dk>                                |
// +----------------------------------------------------------------------+
//



/**
* getID3() settings
*/

require_once('getid3/getid3.php');




/**
* Class for extracting information from audio files with getID3().
*/

class AudioInfo {

	/**
	* Private variables
	*/
	var $result = NULL;
	var $info   = NULL;




	/**
	* Constructor
	*/

	function AudioInfo() {

		// Initialize getID3 engine
		$this->getID3 = new getID3;
		$this->getID3->option_md5_data        = true;
		$this->getID3->option_md5_data_source = true;
		$this->getID3->encoding               = 'UTF-8';
	}




	/**
	* Extract information - only public function
	*
	* @access   public
	* @param    string  file    Audio file to extract info from.
	*/

	function Info($file) {

		// Analyze file
		$this->info = $this->getID3->analyze($file);

		// Exit here on error
		if (isset($this->info['error'])) {
			return array ('error' => $this->info['error']);
		}

		// Init wrapper object
		$this->result = array ();
		$this->result['format_name']     = @$this->info['fileformat'].'/'.@$this->info['audio']['dataformat'].(isset($this->info['video']['dataformat']) ? '/'.@$this->info['video']['dataformat'] : '');
		$this->result['encoder_version'] = @$this->info['audio']['encoder'];
		$this->result['encoder_options'] = @$this->info['audio']['encoder_options'];
		$this->result['bitrate_mode']    = @$this->info['audio']['bitrate_mode'];
		$this->result['channels']        = @$this->info['audio']['channels'];
		$this->result['sample_rate']     = @$this->info['audio']['sample_rate'];
		$this->result['bits_per_sample'] = @$this->info['audio']['bits_per_sample'];
		$this->result['playing_time']    = @$this->info['playtime_seconds'];
		$this->result['avg_bit_rate']    = @$this->info['audio']['bitrate'];
		$this->result['tags']            = @$this->info['tags'];
		$this->result['comments']        = @$this->info['comments'];
		$this->result['warning']         = @$this->info['warning'];
		$this->result['md5']             = @$this->info['md5_data'];

		// Post getID3() data handling based on file format
		$method = @$this->info['fileformat'].'Info';
		if (@$this->info['fileformat'] && method_exists($this, $method)) {
			$this->$method();
		}

		return $this->result;
	}




	/**
	* post-getID3() data handling for AAC files.
	*
	* @access   private
	*/

	function aacInfo() {
		$this->result['format_name']     = 'AAC';
	}




	/**
	* post-getID3() data handling for Wave files.
	*
	* @access   private
	*/

	function riffInfo() {
		if ($this->info['audio']['dataformat'] == 'wav') {

			$this->result['format_name'] = 'Wave';

		} else if (ereg('^mp[1-3]$', $this->info['audio']['dataformat'])) {

			$this->result['format_name'] = strtoupper($this->info['audio']['dataformat']);

		} else {

			$this->result['format_name'] = 'riff/'.$this->info['audio']['dataformat'];

		}
	}




	/**
	* * post-getID3() data handling for FLAC files.
	*
	* @access   private
	*/

	function flacInfo() {
		$this->result['format_name']     = 'FLAC';
	}





	/**
	* post-getID3() data handling for Monkey's Audio files.
	*
	* @access   private
	*/

	function macInfo() {
		$this->result['format_name']     = 'Monkey\'s Audio';
	}





	/**
	* post-getID3() data handling for Lossless Audio files.
	*
	* @access   private
	*/

	function laInfo() {
		$this->result['format_name']     = 'La';
	}





	/**
	* post-getID3() data handling for Ogg Vorbis files.
	*
	* @access   private
	*/

	function oggInfo() {
		if ($this->info['audio']['dataformat'] == 'vorbis') {

			$this->result['format_name']     = 'Ogg Vorbis';

		} else if ($this->info['audio']['dataformat'] == 'flac') {

			$this->result['format_name'] = 'Ogg FLAC';

		} else if ($this->info['audio']['dataformat'] == 'speex') {

			$this->result['format_name'] = 'Ogg Speex';

		} else {

			$this->result['format_name'] = 'Ogg '.$this->info['audio']['dataformat'];

		}
	}




	/**
	* post-getID3() data handling for Musepack files.
	*
	* @access   private
	*/

	function mpcInfo() {
		$this->result['format_name']     = 'Musepack';
	}




	/**
	* post-getID3() data handling for MPEG files.
	*
	* @access   private
	*/

	function mp3Info() {
		$this->result['format_name']     = 'MP3';
	}




	/**
	* post-getID3() data handling for MPEG files.
	*
	* @access   private
	*/

	function mp2Info() {
		$this->result['format_name']     = 'MP2';
	}





	/**
	* post-getID3() data handling for MPEG files.
	*
	* @access   private
	*/

	function mp1Info() {
		$this->result['format_name']     = 'MP1';
	}




	/**
	* post-getID3() data handling for WMA files.
	*
	* @access   private
	*/

	function asfInfo() {
		$this->result['format_name']     = strtoupper($this->info['audio']['dataformat']);
	}



	/**
	* post-getID3() data handling for Real files.
	*
	* @access   private
	*/

	function realInfo() {
		$this->result['format_name']     = 'Real';
	}





	/**
	* post-getID3() data handling for VQF files.
	*
	* @access   private
	*/

	function vqfInfo() {
		$this->result['format_name']     = 'VQF';
	}

}


// END of the part extracted from getID3

$fo=fopen("$foname.wlmp",'w'); 
$firstvideoclip=0;
$lastvideoclip=0; // assuming that all audio clips are placed after the video clips
$firstaudioclip=0;
$lastclip=0;
if(!$fo)
{
  echo "Unable to open output file $foname.wlmp\n";
  exit(1);
}
else
  echo "$foname.wlmp created\n";
fputs($fo,"<?xml version=\"1.0\" encoding=\"utf-8\"?".">\n");
fputs($fo,"<Project name=\"$foname\" themeId=\"0\" version=\"65538\" templateID=\"SimpleProjectTemplate\">\n");
fputs($fo,"  <MediaItems>\n");
$ni=0;
echo "Reading pictures";
if ($handle = opendir($dir)) 
{
	while (false !== ($file = readdir($handle))) 
  {
    if(preg_match('/\.jpg$/i',$file))
    {
      $ni++;
      if(!$firstvideoclip)
        $firstvideoclip=1;
      $lastclip=$lastvideoclip=$ni;
      $imgdata=getimagesize($dir . "\\" . $file);
      echo ".";
      fputs($fo,"    <MediaItem id=\"$ni\" filePath=\"" . xmlentities(realpath("$dir\\$file")) . "\" arWidth=\"" . $imgdata[0] . "\" arHeight=\"" . $imgdata[1] . "\" duration=\"0\" songTitle=\"\" songArtist=\"\" songAlbum=\"\" />\n");  
    }
  }
} 
echo "\n";

$au = new AudioInfo();                                             
echo "Reading music";
if ($handle = opendir($mp3dir)) 
{
	while (false !== ($file = readdir($handle))) 
  {
    if(preg_match('/\.mp3$/i',$file))
    {
      $ni++;
      if(!$firstaudioclip)
        $firstaudioclip=$lastvideoclip+1;
      $lastclip=$ni;
      $audiodata=$au->Info($mp3dir . "\\" . $file);
      echo ".";
      @fputs($fo,"    <MediaItem id=\"$ni\" filePath=\"" . xmlentities(realpath("$mp3dir\\$file")) . "\" arWidth=\"0\" arHeight=\"0\" duration=\"" . $audiodata['playing_time'] . "\" songTitle=\"" . xmlentities($audiodata['tags']['id3v1']['title'][0]) . "\" songArtist=\"" . xmlentities($audiodata['tags']['id3v1']['artist'][0]) . "\" songAlbum=\"" . xmlentities($audiodata['tags']['id3v1']['album'][0]) . "\" />\n");  
    } 
  }
} 
echo "\n";

fputs($fo,"  </MediaItems>\n");
echo "Writing extents...\n";
fputs($fo,"  <Extents>\n");
if($firstvideoclip)
{
  for($i=$firstvideoclip;$i<=$lastvideoclip;$i++)
  {
    $ne=4+$i;
    fputs($fo,"    <ImageClip extentID=\"$ne\" gapBefore=\"0\" mediaItemID=\"$i\" duration=\"$dur\">\n");
    fputs($fo,"      <Effects />\n");         
    if($i>1)
    {                                                              
      fputs($fo,"      <Transitions>\n");
      fputs($fo,"        <ShaderEffect effectTemplateID=\"" . randomeffect() . "\" duration=\"1.5\">\n");
      fputs($fo,"          <BoundProperties />\n");
      fputs($fo,"        </ShaderEffect>\n");
      fputs($fo,"      </Transitions>\n");
    }
    else
      fputs($fo,"      <Transitions/>\n");
    fputs($fo,"      <BoundProperties>\n");
    fputs($fo,"        <BoundPropertyInt Name=\"rotateStepNinety\" Value=\"0\" />\n");
    fputs($fo,"      </BoundProperties>\n");
    fputs($fo,"    </ImageClip>\n");
  }
}

if($firstaudioclip)
{
  for($i=$firstaudioclip;$i<=$lastclip;$i++)
  {
    $ne=4+$i;
    fputs($fo,"    <AudioClip extentID=\"$ne\" gapBefore=\"2\" mediaItemID=\"$i\" inTime=\"0\" outTime=\"0\">\n");
    fputs($fo,"      <Effects />\n");         
    fputs($fo,"      <Transitions/>\n");
    fputs($fo,"      <BoundProperties>\n");
    fputs($fo,"        <BoundPropertyBool Name=\"Mute\" Value=\"false\" />\n");
    fputs($fo,"        <BoundPropertyFloat Name=\"Volume\" Value=\"1\" />\n");
    fputs($fo,"      </BoundProperties>\n");
    fputs($fo,"    </AudioClip>\n");
  }
}
fputs($fo,"    <ExtentSelector extentID=\"1\" gapBefore=\"0\" primaryTrack=\"true\">\n");
fputs($fo,"      <Effects />\n");
fputs($fo,"      <Transitions />\n");
fputs($fo,"      <BoundProperties />\n");
fputs($fo,"      <ExtentRefs>\n");
for($i=$firstvideoclip;$i<=$lastvideoclip;$i++)
{
  $ne=4+$i;
  fputs($fo,"        <ExtentRef id=\"$ne\" />\n");
}
fputs($fo,"      </ExtentRefs>\n");
fputs($fo,"    </ExtentSelector>\n");
fputs($fo,"    <ExtentSelector extentID=\"2\" gapBefore=\"0\" primaryTrack=\"false\">\n");
fputs($fo,"      <Effects />\n");
fputs($fo,"      <Transitions />\n");
fputs($fo,"      <BoundProperties />\n");
fputs($fo,"      <ExtentRefs>\n");
if($firstaudioclip)
{
  for($i=$firstaudioclip;$i<=$lastclip;$i++)
  {
    $ne=4+$i;
    fputs($fo,"        <ExtentRef id=\"$ne\" />\n");
  }
}
fputs($fo,"      </ExtentRefs>\n");
fputs($fo,"    </ExtentSelector>\n");
fputs($fo,"    <ExtentSelector extentID=\"3\" gapBefore=\"0\" primaryTrack=\"false\">\n");
fputs($fo,"      <Effects />\n");
fputs($fo,"      <Transitions />\n");
fputs($fo,"      <BoundProperties />\n");
fputs($fo,"      <ExtentRefs />\n");
fputs($fo,"    </ExtentSelector>\n");
fputs($fo,"    <ExtentSelector extentID=\"4\" gapBefore=\"0\" primaryTrack=\"false\">\n");
fputs($fo,"      <Effects />\n");
fputs($fo,"      <Transitions />\n");
fputs($fo,"      <BoundProperties />\n");
fputs($fo,"      <ExtentRefs />\n");
fputs($fo,"    </ExtentSelector>\n");
fputs($fo,"  </Extents>\n");
fputs($fo,"  <BoundPlaceholders>\n");
fputs($fo,"    <BoundPlaceholder placeholderID=\"SingleExtentView\" extentID=\"0\" />\n");
fputs($fo,"    <BoundPlaceholder placeholderID=\"Main\" extentID=\"1\" />\n");
fputs($fo,"    <BoundPlaceholder placeholderID=\"SoundTrack\" extentID=\"2\" />\n");
fputs($fo,"    <BoundPlaceholder placeholderID=\"Text\" extentID=\"4\" />\n");
fputs($fo,"    <BoundPlaceholder placeholderID=\"Narration\" extentID=\"3\" />\n");
fputs($fo,"  </BoundPlaceholders>\n");
fputs($fo,"  <BoundProperties>\n");
fputs($fo,"    <BoundPropertyFloatSet Name=\"AspectRatio\">\n");
fputs($fo,"      <BoundPropertyFloatElement Value=\"1.7777776718139648\" />\n");
fputs($fo,"    </BoundPropertyFloatSet>\n");
fputs($fo,"    <BoundPropertyFloat Name=\"SoundTrackMix\" Value=\"0.5\" />\n");
fputs($fo,"  </BoundProperties>\n");
fputs($fo,"  <ThemeOperationLog themeID=\"0\">\n");
fputs($fo,"    <MonolithicThemeOperations />\n");
fputs($fo,"  </ThemeOperationLog>\n");
fputs($fo,"</Project>\n");
fclose($fo);

function randomeffect()
{
  global $effects;
  return $effects[rand(0,count($effects)-1)];
}


function xmlentities($s)
{
  $ret="";
  for($i=0;$i<strlen($s);$i++)
  {
    $c=$s[$i];
    if($c=='<')
      $ret.='&lt;';
    if($c=='>')
      $ret.='&gt;';
    if($c=='&')
      $ret.='&amp;';
    if($c=="'")
      $ret.='&apos;';
    if($c=='"')
      $ret.='&quot;';
    if(ord($c)>126)
      $ret=$ret."&#x" . sprintf("%02x",ord($c)) .";";
    else
      $ret.= $c;
  }
  return $ret;
}

?>